| Title: | Efficiently search the R help pages |
|---|---|
| Description: | Rcmdr interface to the 'sos' package. The plug-in renders the 'sos' searching functionality easily accessible via the Rcmdr menus. It also simplifies the task of performing multiple searches and subsequently obtaining the union or the intersection of the results. |
| Authors: | Liviu Andronic |
| Maintainer: | Liviu Andronic <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.3-0 |
| Built: | 2026-05-28 10:22:35 UTC |
| Source: | https://github.com/cran/RcmdrPlugin.sos |
Rcmdr interface to sos
The plug-in attempts to render the sos searching functionality readily
accessible for casual use. It allows to perform simple searches
(findFn) and more advanced operations such as
filtering the search results (grepFn) or combining
the results of multiple searches (unionFindFn,
intersectFindFn).
For a good overview of the sos package see
vignette("sos", package="sos").
Liviu Andronic [email protected]
Rcmdr,
findFn,
grepFn,
unionFindFn,
## Not run: ## start R library(RcmdrPlugin.sos) ## loads Rcmdr and the plug-in ## End(Not run)## Not run: ## start R library(RcmdrPlugin.sos) ## loads Rcmdr and the plug-in ## End(Not run)
Rcmdr interface to findFn() and grepFn()
sosInit() sosGrep(recall=NULL, bLabel=gettextRcmdr("Filter by"), eLabel=gettextRcmdr("in"), initialLabel=gettextRcmdr("Filter by"))sosInit() sosGrep(recall=NULL, bLabel=gettextRcmdr("Filter by"), eLabel=gettextRcmdr("in"), initialLabel=gettextRcmdr("Filter by"))
recall |
function to call after error. |
bLabel, eLabel, initialLabel
|
strings defining the label of the grep button |
The dialogues provide the user with an interface to perform simple and more advanced searches of the R Help pages via the RSiteSearch functionality.
It is possible to perform multiple searches. One can specify up to
9 search terms separated either by "|" (vertical bars, to obtain the
union of results) or "&" (ampersands, to obtain the intersection).
One may use only one type of separating operator per search. For example,
enter in the search box newey west | newey-west | neweywest or
newey west & newey-west & neweywest, but not
newey west | newey-west & neweywest.
Note that findFn() does not simply search for character strings.
For example, findFn() may find less results for
differential equation than for differential equations.
In such cases you can perform multiple searches as described in the
previous paragraph (differential equation | differential equations).
For more on this issue see vignette("sos", package="sos").
Also note that findFn() performs the searches on-line, via
Jonathan Baron's R Site Search [1]. Depending on how generic the
search term is (for example, correlation) and the quality of the
internet connection, it may take from a couple of seconds up to several
minutes to complete the search and display the results.
NULL
Liviu Andronic [email protected]
[1] http://finzi.psych.upenn.edu/nmz.html